@@ -9,7 +9,7 @@ package org.mule;
 import static org.mule.api.config.MuleProperties.OBJECT_EXPRESSION_LANGUAGE;
 import static org.mule.api.config.MuleProperties.OBJECT_POLLING_CONTROLLER;
 import static org.mule.api.config.MuleProperties.OBJECT_TRANSACTION_MANAGER;
-
+import static org.mule.api.lifecycle.LifecycleUtils.startIfNeeded;
 import org.mule.api.Injector;
 import org.mule.api.MuleContext;
 import org.mule.api.MuleException;
@@ -19,6 +19,7 @@ import org.mule.api.client.LocalMuleClient;
 import org.mule.api.config.MuleConfiguration;
 import org.mule.api.config.MuleProperties;
 import org.mule.api.config.ThreadingProfile;
+import org.mule.api.construct.Pipeline;
 import org.mule.api.context.MuleContextAware;
 import org.mule.api.context.WorkManager;
 import org.mule.api.context.notification.FlowTraceManager;
@@ -34,6 +35,7 @@ import org.mule.api.expression.ExpressionManager;
 import org.mule.api.lifecycle.Disposable;
 import org.mule.api.lifecycle.Initialisable;
 import org.mule.api.lifecycle.InitialisationException;
+import org.mule.api.lifecycle.LifecycleException;
 import org.mule.api.lifecycle.LifecycleManager;
 import org.mule.api.lifecycle.Startable;
 import org.mule.api.lifecycle.Stoppable;
@@ -42,6 +44,8 @@ import org.mule.api.registry.RegistrationException;
 import org.mule.api.registry.Registry;
 import org.mule.api.security.SecurityManager;
 import org.mule.api.serialization.ObjectSerializer;
+import org.mule.api.service.Service;
+import org.mule.api.source.MessageSource;
 import org.mule.api.store.ListableObjectStore;
 import org.mule.api.store.ObjectStoreManager;
 import org.mule.api.util.StreamCloserService;
@@ -63,6 +67,8 @@ import org.mule.management.stats.AllStatistics;
 import org.mule.management.stats.ProcessingTimeWatcher;
 import org.mule.registry.DefaultRegistryBroker;
 import org.mule.registry.MuleRegistryHelper;
+import org.mule.service.Pausable;
+import org.mule.transport.ConnectException;
 import org.mule.transport.DefaultPollingController;
 import org.mule.transport.PollingController;
 import org.mule.util.ApplicationShutdownSplashScreen;
@@ -81,6 +87,7 @@ import java.io.Serializable;
 import java.util.Collection;
 import java.util.HashMap;
 import java.util.Map;
+import java.util.Properties;
 import java.util.Set;
 import java.util.concurrent.TimeUnit;
 
@@ -198,6 +205,8 @@ public class DefaultMuleContext implements MuleContext
      * The {@link ArtifactType} indicating if this configuration object is for an application or a domain.
      */
     private ArtifactType artifactType;
+    
+    private Properties deploymentProperties;
 
     /**
      * @deprecated Use empty constructor instead and use setter for dependencies.
@@ -311,6 +320,7 @@ public class DefaultMuleContext implements MuleContext
         getLifecycleManager().fireLifecycle(Startable.PHASE_NAME);
         overridePollingController();
         overrideClusterConfiguration();
+        startMessageSources();
 
         fireNotification(new MuleContextNotification(this, MuleContextNotification.CONTEXT_STARTED));
 
@@ -323,6 +333,70 @@ public class DefaultMuleContext implements MuleContext
         }
     }
 
+    private void startMessageSources() throws LifecycleException
+    {
+        startPipelineMessageSources();
+        startServicesMessageSources();
+    }
+
+    private void startServicesMessageSources() throws LifecycleException
+    {
+        for (Service service : this.getRegistry().lookupObjects(Service.class))
+        {
+            if (service.isStarted() || service.isPaused())
+            {
+                MessageSource messageSource = service.getMessageSource();
+
+                startMessageSource(messageSource);
+
+                if (service.isPaused() && messageSource instanceof Pausable)
+                {
+                    try
+                    {
+                        ((Pausable) messageSource).pause();
+                    }
+                    catch (Exception e)
+                    {
+                        exceptionListener.handleException(e);
+                    }
+                }
+            }
+        }
+    }
+
+    private void startPipelineMessageSources() throws LifecycleException
+    {
+        for (Pipeline pipeline : this.getRegistry().lookupObjects(Pipeline.class))
+        {
+            if (pipeline.getLifecycleState().isStarted())
+            {
+                MessageSource messageSource = pipeline.getMessageSource();
+
+                startMessageSource(messageSource);
+            }
+        }
+    }
+
+    private void startMessageSource(MessageSource messageSource) throws LifecycleException
+    {
+        try
+        {
+            startIfNeeded(messageSource);
+        }
+        catch (ConnectException e)
+        {
+            exceptionListener.handleException(e);
+        }
+        catch (LifecycleException le)
+        {
+            throw le;
+        }
+        catch (Exception e)
+        {
+            throw new LifecycleException(e, messageSource);
+        }
+    }
+
     /**
      * Stops the <code>MuleContext</code> which stops all sessions and
      * connectors
@@ -343,7 +417,9 @@ public class DefaultMuleContext implements MuleContext
     @Override
     public synchronized void dispose()
     {
-        if (isStarted())
+        if (isStarted() || (lifecycleManager.getLastPhaseExecuted() != null
+                            && (lifecycleManager.getLastPhaseExecuted().equals(Startable.PHASE_NAME)
+                                && lifecycleManager.isLastPhaseExecutionFailed())))
         {
             try
             {
@@ -846,8 +922,8 @@ public class DefaultMuleContext implements MuleContext
     protected SplashScreen buildStartupSplash()
     {
         SplashScreen startupScreen = config.isContainerMode()
-                                         ? new ApplicationStartupSplashScreen()
-                                         : new ServerStartupSplashScreen();
+                                     ? new ApplicationStartupSplashScreen()
+                                     : new ServerStartupSplashScreen();
         startupScreen.setHeader(this);
         startupScreen.setFooter(this);
         return startupScreen;
@@ -856,8 +932,8 @@ public class DefaultMuleContext implements MuleContext
     protected SplashScreen buildShutdownSplash()
     {
         SplashScreen shutdownScreen = config.isContainerMode()
-                                         ? new ApplicationShutdownSplashScreen()
-                                         : new ServerShutdownSplashScreen();
+                                      ? new ApplicationShutdownSplashScreen()
+                                      : new ServerShutdownSplashScreen();
         shutdownScreen.setHeader(this);
         return shutdownScreen;
     }
@@ -949,7 +1025,7 @@ public class DefaultMuleContext implements MuleContext
             defaultExceptionStrategy = getRegistry().lookupObject(config.getDefaultExceptionStrategyName());
             if (defaultExceptionStrategy == null)
             {
-                throw new MuleRuntimeException(CoreMessages.createStaticMessage(String.format("No global exception strategy named %s",config.getDefaultExceptionStrategyName())));
+                throw new MuleRuntimeException(CoreMessages.createStaticMessage(String.format("No global exception strategy named %s", config.getDefaultExceptionStrategyName())));
             }
         }
         else
@@ -1163,4 +1239,22 @@ public class DefaultMuleContext implements MuleContext
         }
         return exceptionContextProviders;
     }
+
+    @Override
+    public Properties getDeploymentProperties()
+    {
+        return deploymentProperties;
+    }
+
+    /**
+     * Sets the deployment properties so that beans as well as
+     * application properties are overridden.
+     * 
+     * @since 3.9.0
+     */
+    public void setDeploymentProperties(Properties deploymentProperties)
+    {
+        this.deploymentProperties = deploymentProperties;
+        
+    }
 }
