@@ -1,13 +1,9 @@
 /*
- * $Id$
- * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
- *
  * The software in this package is published under the terms of the CPAL v1.0
  * license, a copy of which has been included with this distribution in the
  * LICENSE.txt file.
  */
-
 package org.mule.expression;
 
 import org.mule.api.expression.ExpressionManager;
@@ -34,6 +30,7 @@ public class ExpressionConfig
 
     private String expressionPrefix = ExpressionManager.DEFAULT_EXPRESSION_PREFIX;
     private String expressionPostfix = ExpressionManager.DEFAULT_EXPRESSION_POSTFIX;
+    private volatile boolean parsed = false;
 
     public ExpressionConfig()
     {
@@ -61,6 +58,26 @@ public class ExpressionConfig
     }
 
     public void parse(String expressionString)
+    {
+        if (parsed)
+        {
+            return;
+        }
+
+        synchronized (this)
+        {
+            if (parsed)
+            {
+                return;
+            }
+
+            doParse(expressionString);
+
+            parsed = true;
+        }
+    }
+
+    private void doParse(String expressionString)
     {
         if (expressionString.startsWith(expressionPrefix) && evaluator == null)
         {
@@ -81,7 +98,7 @@ public class ExpressionConfig
             }
             else
             {
-                this.evaluator = expressionString.substring(0, i);
+                this.evaluator = candidateEvaluator;
                 this.expression = expressionString.substring(i + 1);
             }
         }
@@ -186,5 +203,6 @@ public class ExpressionConfig
         this.unParsedExpression = expression;
         this.expression = null;
         this.fullExpression = null;
+        this.parsed = false;
     }
 }
