@@ -1,17 +1,12 @@
 /*
- * $Id: MessageHeadersExpressionEvaluator.java 19191 2010-08-25 21:05:23Z tcarlson $
- * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
- *
  * The software in this package is published under the terms of the CPAL v1.0
  * license, a copy of which has been included with this distribution in the
  * LICENSE.txt file.
  */
-
 package org.mule.expression;
 
 import org.mule.api.MuleMessage;
-import org.mule.api.expression.ExpressionEvaluator;
 
 import java.util.Map;
 
@@ -23,7 +18,7 @@ import java.util.Map;
  * @see org.mule.api.expression.ExpressionEvaluator
  * @see DefaultExpressionManager
  */
-public class MessageHeadersExpressionEvaluator implements ExpressionEvaluator, ExpressionConstants
+public class MessageHeadersExpressionEvaluator extends AbstractExpressionEvaluator
 {
     public static final String NAME = "headers";
 
@@ -40,11 +35,4 @@ public class MessageHeadersExpressionEvaluator implements ExpressionEvaluator, E
         return NAME;
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public void setName(String name)
-    {
-        throw new UnsupportedOperationException();
-    }
 }
