@@ -6,6 +6,9 @@
  */
 package org.mule.module.launcher.domain;
 
+import static org.mule.config.bootstrap.ArtifactType.DOMAIN;
+
+import org.mule.DefaultMuleContext;
 import org.mule.api.config.MuleConfiguration;
 import org.mule.api.context.notification.ClusterNodeNotificationListener;
 import org.mule.api.context.notification.ConnectionNotificationListener;
@@ -25,6 +28,8 @@ import org.mule.context.notification.MuleContextNotification;
 import org.mule.context.notification.SecurityNotification;
 import org.mule.context.notification.ServerNotificationManager;
 
+import java.util.Properties;
+
 /**
  * Builder for domain MuleContext instance.
  */
@@ -38,6 +43,14 @@ public class DomainMuleContextBuilder extends DefaultMuleContextBuilder
         this.domainId = domainId;
     }
 
+    @Override
+    protected DefaultMuleContext createDefaultMuleContext()
+    {
+        DefaultMuleContext muleContext = super.createDefaultMuleContext();
+        muleContext.setArtifactType(DOMAIN);
+        return muleContext;
+    }
+
     @Override
     protected MuleConfiguration getMuleConfiguration()
     {
