@@ -1,18 +1,26 @@
 /*
- * $Id: ReversibleXMLStreamReader.java 19191 2010-08-25 21:05:23Z tcarlson $
- * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
- *
  * The software in this package is published under the terms of the CPAL v1.0
  * license, a copy of which has been included with this distribution in the
  * LICENSE.txt file.
  */
-
 package org.mule.module.xml.stax;
 
 import java.util.ArrayList;
 import java.util.List;
 
+import javax.xml.namespace.NamespaceContext;
+import javax.xml.namespace.QName;
+import javax.xml.stream.Location;
+import javax.xml.stream.XMLStreamConstants;
+import javax.xml.stream.XMLStreamException;
+import javax.xml.stream.XMLStreamReader;
+import javax.xml.stream.events.Attribute;
+import javax.xml.stream.events.Characters;
+import javax.xml.stream.events.Namespace;
+import javax.xml.stream.events.XMLEvent;
+
+import javanet.staxutils.events.AbstractCharactersEvent;
 import javanet.staxutils.events.AttributeEvent;
 import javanet.staxutils.events.CDataEvent;
 import javanet.staxutils.events.CharactersEvent;
@@ -23,29 +31,20 @@ import javanet.staxutils.events.NamespaceEvent;
 import javanet.staxutils.events.StartDocumentEvent;
 import javanet.staxutils.events.StartElementEvent;
 
-import javax.xml.namespace.NamespaceContext;
-import javax.xml.namespace.QName;
-import javax.xml.stream.Location;
-import javax.xml.stream.XMLStreamConstants;
-import javax.xml.stream.XMLStreamException;
-import javax.xml.stream.XMLStreamReader;
-import javax.xml.stream.events.Attribute;
-import javax.xml.stream.events.Namespace;
-import javax.xml.stream.events.XMLEvent;
-
 public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
 {
-    private List events;
+    private List<XMLEvent> events;
     private XMLEvent current;
     private int replayIndex;
     private boolean tracking = false;
     private boolean replay = false;
-    
+
     public ReversibleXMLStreamReader(XMLStreamReader reader)
     {
         super(reader);
     }
 
+    @Override
     public int nextTag() throws XMLStreamException
     {
         int eventType = next();
@@ -79,18 +78,19 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
     public void setTracking(boolean tracking)
     {
         this.tracking = tracking;
-        
+
         if (tracking)
         {
             replayIndex = 0;
-            
+
             if (events == null)
             {
-                events = new ArrayList();
+                events = new ArrayList<XMLEvent>();
             }
         }
     }
 
+    @Override
     public int next() throws XMLStreamException
     {
         int event;
@@ -111,8 +111,8 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         {
             event = super.next();
         }
-        
-        if (tracking && !replay) 
+
+        if (tracking && !replay)
         {
             capture(event);
         }
@@ -122,7 +122,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
 
     private int getReplayEvent()
     {
-        current = (XMLEvent) events.get(replayIndex);
+        current = events.get(replayIndex);
         replayIndex++;
 
         return current.getEventType();
@@ -130,7 +130,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
 
     /**
      * Capture the current event;
-     * 
+     *
      * @param event
      */
     private void capture(int event)
@@ -148,7 +148,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
                 events.add(createStartElementEvent());
                 break;
             case XMLStreamConstants.END_ELEMENT :
-                events.add(new EndElementEvent(getName(), getNamespaces().iterator(), getLocation()));
+                events.add(new EndElementEventX(getName(), getNamespaces()));
                 break;
             case XMLStreamConstants.CDATA :
                 events.add(new CDataEvent(getText(), getLocation()));
@@ -176,7 +176,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
 
     private StartElementEvent createStartElementEvent()
     {
-        List attributes = new ArrayList();
+        List<AttributeEvent> attributes = new ArrayList<AttributeEvent>();
         for (int i = 0; i < getAttributeCount(); i++)
         {
             attributes.add(new AttributeEvent(getAttributeName(i), getAttributeValue(i)));
@@ -198,9 +198,9 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         return ctx;
     }
 
-    private List getNamespaces()
+    private List<Namespace> getNamespaces()
     {
-        List namespaces = new ArrayList();
+        List<Namespace> namespaces = new ArrayList<Namespace>();
         for (int i = 0; i < getNamespaceCount(); i++)
         {
             namespaces.add(new NamespaceEvent(getNamespacePrefix(i), getNamespaceURI(i), getLocation()));
@@ -208,6 +208,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         return namespaces;
     }
 
+    @Override
     public String getElementText() throws XMLStreamException
     {
         if (getEventType() != XMLStreamConstants.START_ELEMENT)
@@ -216,7 +217,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
 
         int eventType = next();
-        StringBuffer buf = new StringBuffer();
+        StringBuilder buf = new StringBuilder();
         while (eventType != XMLStreamConstants.END_ELEMENT)
         {
             if (eventType == XMLStreamConstants.CHARACTERS || eventType == XMLStreamConstants.CDATA
@@ -248,6 +249,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
 
     }
 
+    @Override
     public int getAttributeCount()
     {
         if (replay)
@@ -260,6 +262,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public String getAttributeLocalName(int i)
     {
 
@@ -268,12 +271,13 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
             Attribute att = (Attribute) ((StartElementEventX) current).getAttributeList().get(i);
             return att.getName().getLocalPart();
         }
-        else 
+        else
         {
             return super.getAttributeLocalName(i);
         }
     }
 
+    @Override
     public QName getAttributeName(int i)
     {
 
@@ -288,6 +292,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public String getAttributeNamespace(int i)
     {
 
@@ -302,6 +307,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public String getAttributePrefix(int i)
     {
         if (replay)
@@ -315,6 +321,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public String getAttributeType(int i)
     {
         if (replay)
@@ -328,6 +335,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public String getAttributeValue(int i)
     {
         if (replay)
@@ -341,6 +349,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public String getAttributeValue(String ns, String local)
     {
         if (replay)
@@ -361,13 +370,14 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public int getEventType()
     {
         if (replay)
         {
             if (current == null)
             {
-                return START_DOCUMENT;
+                return -1;
             }
             return current.getEventType();
         }
@@ -377,6 +387,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public String getLocalName()
     {
         if (replay)
@@ -385,7 +396,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
             {
                 return ((StartElementEventX) current).getName().getLocalPart();
             }
-            else 
+            else
             {
                 return ((EndElementEvent) current).getName().getLocalPart();
             }
@@ -396,6 +407,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public Location getLocation()
     {
         if (replay)
@@ -408,6 +420,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public QName getName()
     {
         if (replay)
@@ -416,7 +429,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
             {
                 return ((StartElementEventX) current).getName();
             }
-            else 
+            else
             {
                 return ((EndElementEvent) current).getName();
             }
@@ -427,6 +440,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public NamespaceContext getNamespaceContext()
     {
         if (replay)
@@ -439,11 +453,19 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public int getNamespaceCount()
     {
         if (replay)
         {
-            return ((StartElementEventX) current).getNamespaceList().size();
+            if(isStartElement())
+            {
+                return ((StartElementEventX) current).getNamespaceList().size();
+            }
+            else
+            {
+                return ((EndElementEventX) current).getNamespaceList().size();
+            }
         }
         else
         {
@@ -451,13 +473,23 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public String getNamespacePrefix(int arg0)
     {
         if (replay)
         {
-            Namespace ns = (Namespace) ((StartElementEventX) current).getNamespaceList().get(arg0);
-            
-            return ns.getPrefix();
+            if(isStartElement())
+            {
+                Namespace ns = (Namespace) ((StartElementEventX) current).getNamespaceList().get(arg0);
+
+                return ns.getPrefix();
+            }
+            else
+            {
+                Namespace ns = ((EndElementEventX) current).getNamespaceList().get(arg0);
+
+                return ns.getPrefix();
+            }
         }
         else
         {
@@ -465,6 +497,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public String getNamespaceURI()
     {
         if (replay)
@@ -473,7 +506,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
             {
                 return ((StartElementEventX) current).getName().getNamespaceURI();
             }
-            else 
+            else
             {
                 return ((EndElementEvent) current).getName().getNamespaceURI();
             }
@@ -484,12 +517,13 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public String getNamespaceURI(int arg0)
     {
         if (replay)
         {
             Namespace ns = (Namespace) ((StartElementEventX) current).getNamespaceList().get(arg0);
-            
+
             return ns.getNamespaceURI();
         }
         else
@@ -498,6 +532,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public String getNamespaceURI(String prefix)
     {
         if (replay)
@@ -510,6 +545,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public String getPIData()
     {
         if (replay)
@@ -522,6 +558,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public String getPITarget()
     {
         if (replay)
@@ -534,6 +571,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public String getPrefix()
     {
         if (replay)
@@ -542,7 +580,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
             {
                 return ((StartElementEventX) current).getName().getPrefix();
             }
-            else 
+            else
             {
                 return ((EndElementEvent) current).getName().getPrefix();
             }
@@ -553,6 +591,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public String getText()
     {
         if (replay)
@@ -563,7 +602,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
             }
             else
             {
-                return ((CharactersEvent) current).getData();
+                return ((AbstractCharactersEvent) current).getData();
             }
         }
         else
@@ -572,6 +611,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public char[] getTextCharacters()
     {
         if (replay)
@@ -584,6 +624,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public int getTextCharacters(int sourceStart, char[] target, int targetStart, int length) throws XMLStreamException
     {
         if (replay)
@@ -606,6 +647,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public int getTextLength()
     {
         if (replay)
@@ -618,6 +660,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public int getTextStart()
     {
         if (replay)
@@ -630,6 +673,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public boolean hasName()
     {
         if (replay)
@@ -642,11 +686,12 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public boolean hasNext() throws XMLStreamException
     {
         if (replay)
         {
-            if (replayIndex == events.size()) 
+            if (replayIndex == events.size())
             {
                 return super.hasNext();
             }
@@ -661,6 +706,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public boolean hasText()
     {
         if (replay)
@@ -675,6 +721,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public boolean isAttributeSpecified(int i)
     {
         if (replay)
@@ -688,6 +735,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public boolean isCharacters()
     {
         if (replay)
@@ -700,6 +748,7 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public boolean isEndElement()
     {
         if (replay)
@@ -713,11 +762,12 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
     }
 
 
+    @Override
     public boolean isStartElement()
     {
         if (replay)
         {
-            return current.isStartElement();
+            return current != null && current.isStartElement();
         }
         else
         {
@@ -725,10 +775,15 @@ public class ReversibleXMLStreamReader extends DelegateXMLStreamReader
         }
     }
 
+    @Override
     public boolean isWhiteSpace()
     {
         if (replay)
         {
+            if (current instanceof Characters)
+            {
+                return ((Characters) current).isWhiteSpace();
+            }
             return current.getEventType() == SPACE;
         }
         else
