@@ -1,19 +1,15 @@
 /*
- * $Id: AbstractMessageSequenceSplitter.java 24265 2012-04-16 06:54:00Z dfeist $
- * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
- *
  * The software in this package is published under the terms of the CPAL v1.0
  * license, a copy of which has been included with this distribution in the
  * LICENSE.txt file.
  */
-
 package org.mule.routing.outbound;
 
 import org.mule.DefaultMuleEvent;
 import org.mule.DefaultMuleMessage;
-import org.mule.VoidMuleEvent;
 import org.mule.RequestContext;
+import org.mule.VoidMuleEvent;
 import org.mule.api.MuleContext;
 import org.mule.api.MuleEvent;
 import org.mule.api.MuleException;
@@ -26,18 +22,20 @@ import org.mule.routing.AbstractSplitter;
 import org.mule.routing.CorrelationMode;
 import org.mule.routing.DefaultRouterResultsHandler;
 import org.mule.routing.MessageSequence;
+import org.mule.util.CollectionUtils;
 
 import java.util.ArrayList;
+import java.util.Collection;
 import java.util.List;
 
+import org.apache.commons.collections.Transformer;
+
 /**
- * Base implementation of a {@link MuleMessage} splitter, that converts its payload 
- * in a {@link MessageSequence}, and process each element of it.     
- * Implementations must implement {@link #splitMessageIntoSequence(MuleEvent)} and determine how 
- * the message is split.
+ * Base implementation of a {@link MuleMessage} splitter, that converts its payload in a {@link MessageSequence}, and
+ * process each element of it. Implementations must implement {@link #splitMessageIntoSequence(MuleEvent)} and determine
+ * how the message is split.
  * <p>
- * <b>EIP Reference:</b> <a
- * href="http://www.eaipatterns.com/Sequencer.html">http://www
+ * <b>EIP Reference:</b> <a href="http://www.eaipatterns.com/Sequencer.html">http://www
  * .eaipatterns.com/Sequencer.html</a>
  * 
  * @author flbulgarelli
@@ -53,14 +51,23 @@ public abstract class AbstractMessageSequenceSplitter extends AbstractIntercepti
     protected int batchSize;
     protected String counterVariableName;
 
-    public final MuleEvent process(MuleEvent event) throws MuleException
+    @Override
+    public MuleEvent process(MuleEvent event) throws MuleException
     {
         if (isSplitRequired(event))
         {
             MessageSequence<?> seq = splitMessageIntoSequence(event);
             if (!seq.isEmpty())
             {
-                return resultsHandler.aggregateResults(processParts(seq, event), event, muleContext);
+                MuleEvent aggregatedResults = resultsHandler.aggregateResults(processParts(seq, event), event, muleContext);
+                if (aggregatedResults instanceof VoidMuleEvent)
+                {
+                    return null;
+                }
+                else
+                {
+                    return aggregatedResults;
+                }
             }
             else
             {
@@ -80,8 +87,7 @@ public abstract class AbstractMessageSequenceSplitter extends AbstractIntercepti
     }
 
     /**
-     * Converts the event into a {@link MessageSequence} that will retrieve each of
-     * the event elements
+     * Converts the event into a {@link MessageSequence} that will retrieve each of the event elements
      * 
      * @param event the event to split
      * @return a sequence of elements
@@ -108,6 +114,26 @@ public abstract class AbstractMessageSequenceSplitter extends AbstractIntercepti
         for (; messageSequence.hasNext();)
         {
             Object payload = messageSequence.next();
+
+            if (payload instanceof Collection)
+            {
+                payload = CollectionUtils.collect((Collection) payload, new Transformer()
+                {
+                    @Override
+                    public Object transform(Object input)
+                    {
+                        if (input instanceof MuleMessage)
+                        {
+                            return ((MuleMessage) input).getPayload();
+                        }
+                        else
+                        {
+                            return input;
+                        }
+                    }
+                });
+            }
+
             MuleMessage message = createMessage(payload, originalEvent.getMessage());
             correlationSequence++;
             if (counterVariableName != null)
@@ -139,7 +165,7 @@ public abstract class AbstractMessageSequenceSplitter extends AbstractIntercepti
         }
         if (correlationSequence == 1)
         {
-            logger.warn("Splitter only returned a single result. If this is not expected, please check your split expression");
+            logger.debug("Splitter only returned a single result. If this is not expected, please check your split expression");
         }
         return resultEvents;
     }
@@ -183,4 +209,4 @@ public abstract class AbstractMessageSequenceSplitter extends AbstractIntercepti
     {
         this.counterVariableName = counterVariableName;
     }
-}
\ No newline at end of file
+}
