@@ -6,16 +6,22 @@
  */
 package org.mule.tck.listener;
 
+import static java.lang.Double.valueOf;
+import static org.hamcrest.Matchers.closeTo;
+import static org.junit.Assert.assertThat;
 import static org.junit.Assert.fail;
+
+import java.util.concurrent.CountDownLatch;
+import java.util.concurrent.TimeUnit;
+
+import com.google.common.base.Optional;
 import org.mule.api.MuleContext;
 import org.mule.api.context.notification.ConnectionNotificationListener;
 import org.mule.context.notification.ConnectionNotification;
 import org.mule.context.notification.NotificationException;
+import org.mule.util.Preconditions;
 import org.mule.util.concurrent.Latch;
 
-import java.util.concurrent.CountDownLatch;
-import java.util.concurrent.TimeUnit;
-
 /**
  * Listener for connection notifications.
  */
@@ -24,6 +30,8 @@ public class ConnectionListener
 
     private CountDownLatch notificationReceivedLatch = new Latch();
     private int timeout = 10000;
+    private Optional<Long> previousNotificationTimestamp = Optional.absent();
+    private Optional<Long> minimumTimeBetweenNotifications = Optional.absent();
     private int expectedAction = ConnectionNotification.CONNECTION_CONNECTED;
 
     public ConnectionListener(MuleContext muleContext)
@@ -37,6 +45,16 @@ public class ConnectionListener
                 {
                     if (notification.getAction() == expectedAction)
                     {
+                        long currentNotificationTimestamp = System.currentTimeMillis();
+                        if (previousNotificationTimestamp.isPresent())
+                        {
+                            long timeBetweenNotifications = currentNotificationTimestamp - previousNotificationTimestamp.get();
+                            if (!minimumTimeBetweenNotifications.isPresent() || minimumTimeBetweenNotifications.get() > timeBetweenNotifications)
+                            {
+                                minimumTimeBetweenNotifications = Optional.of(timeBetweenNotifications);
+                            }
+                        }
+                        previousNotificationTimestamp = Optional.of(currentNotificationTimestamp);
                         notificationReceivedLatch.countDown();
                     }
                 }
@@ -93,4 +111,13 @@ public class ConnectionListener
         return this;
     }
 
+    /**
+     * @return the minimum time tracked between all received notifications
+     * @throws IllegalStateException if there were less than two notifications received
+     */
+    public void assertMinimumTimeBetweenNotifications(double expectedTimeBetweenNotifications, double delta)
+    {
+        Preconditions.checkState(minimumTimeBetweenNotifications.isPresent(), "At least two notifications must be received in order to get the minimum time between notifications");
+        assertThat(valueOf(minimumTimeBetweenNotifications.get()), closeTo(expectedTimeBetweenNotifications, delta));
+    }
 }
